==> epi2melabs_wfpage-0.2.5.tar.gz: epi2melabs_wfpage-0.2.5/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [v0.2.5]
### Fixed
- Parameter sections erroneously showing invalid

## [v0.2.4]
### Changed
- Overhauled file browser experience
- Improved workflow launch with helpful tooltips
- General refactoring and tidying
### Fixed
- Fixed various bugs
- Polling for workflows enabled

## [v0.2.3]
### Changed
- Get back to referring to tutorials correctly
- Slightly enhance file browser UX
### Fixed
- Fixed certain panel widths

## [v0.2.2]
### Changed
- Adjust ordering of notebook tabs

## [v0.2.1]
### Fixed
- Prevented Notebooks from going missing

## [v0.2.0]
### Changed
- Re-worked user interface prior to 1.0.0

## [v0.1.10]
### Fixed
- fontawesome libraries now on stable versions
- curr dir paths are now converted for use in wsl

## [v0.1.9]
### Changed
- File browser now collapsed by default
- HTML Reports opened from an instance page are now trusted
### Fixed
- Workflow parameters are now correctly ordered
- Pages now extend properly to full height

## [v0.1.8]
### Changed
- Workflow name field now highlights red if it is invalid

## [v0.1.7]
### Added
- Notebooks screen now provides access to the EPI2ME labs notebook roster
- User naming for workflows
- Quick access to report
### Changed
- History and Workflow lists are now consolidated
- Http and S3 paths are now not validated (temporary)
- Various improvements to error handling

## [v0.1.6]
### Added
- Switch between log views
- Rerun workflow with default params from instance
### Changed
- General UI/UX improvements
- Refactor of server-side endpoints

## [v0.1.5]
### Changed
- File picker now operates as a popover.
- Minor fixes and layout changes

## [v0.1.4]
### Added
- First version of file picker.

## [v0.1.3]
### Changed
- CI update.

==> epi2melabs_wfpage-0.2.6.tar.gz: epi2melabs_wfpage-0.2.6/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [v0.2.6]
### Added
- Run with demo data feature enabled
- Trust notebooks when opened via the extension UI
- Filebrowser can now display windows drives

## [v0.2.5]
### Fixed
- Parameter sections erroneously showing invalid

## [v0.2.4]
### Changed
- Overhauled file browser experience
- Improved workflow launch with helpful tooltips
- General refactoring and tidying
### Fixed
- Fixed various bugs
- Polling for workflows enabled

## [v0.2.3]
### Changed
- Get back to referring to tutorials correctly
- Slightly enhance file browser UX
### Fixed
- Fixed certain panel widths

## [v0.2.2]
### Changed
- Adjust ordering of notebook tabs

## [v0.2.1]
### Fixed
- Prevented Notebooks from going missing

## [v0.2.0]
### Changed
- Re-worked user interface prior to 1.0.0

## [v0.1.10]
### Fixed
- fontawesome libraries now on stable versions
- curr dir paths are now converted for use in wsl

## [v0.1.9]
### Changed
- File browser now collapsed by default
- HTML Reports opened from an instance page are now trusted
### Fixed
- Workflow parameters are now correctly ordered
- Pages now extend properly to full height

## [v0.1.8]
### Changed
- Workflow name field now highlights red if it is invalid

## [v0.1.7]
### Added
- Notebooks screen now provides access to the EPI2ME labs notebook roster
- User naming for workflows
- Quick access to report
### Changed
- History and Workflow lists are now consolidated
- Http and S3 paths are now not validated (temporary)
- Various improvements to error handling

## [v0.1.6]
### Added
- Switch between log views
- Rerun workflow with default params from instance
### Changed
- General UI/UX improvements
- Refactor of server-side endpoints

## [v0.1.5]
### Changed
- File picker now operates as a popover.
- Minor fixes and layout changes

## [v0.1.4]
### Added
- First version of file picker.

## [v0.1.3]
### Changed
- CI update.
